@@ -189,7 +189,7 @@ namespace usbguard
     std::function<std::string(const std::string&, const struct dirent*)> filter,
     std::function<int(const std::string&, const std::string&)> loader,
     std::function<bool(const std::pair<std::string, std::string>&, const std::pair<std::string, std::string>&)> sorter = \
-      [](const std::pair<std::string, std::string>& a, const std::pair<std::string, std::string>& b)
+      [](const std::pair<std::string, std::string>& a, const std::pair<std::string, std::string>& b) -> bool
   {
     return a.first < b.first;
   },
@@ -294,6 +294,24 @@ namespace usbguard
     int _fd{-1};
   };
 
+
+  template<typename T>
+  std::string joinElements(T begin, T end, const std::string& separator = " ")
+  {
+    std::ostringstream ss;
+
+    if (begin != end) {
+      ss << *(begin++);
+    }
+
+    while (begin != end) {
+      ss << separator << *(begin++);
+    }
+
+    return ss.str();
+  }
+
+
 } /* namespace usbguard */
 
 /* vim: set ts=2 sw=2 et */
