@@ -63,6 +63,10 @@ namespace usbguard
       const std::string& device_rule,
       uint32_t rule_id);
 
+    void PropertyParameterChanged(const std::string& name,
+      const std::string& value_old,
+      const std::string& value_new);
+
     void ExceptionMessage(const std::string& context,
       const std::string& object,
       const std::string& reason,
