@@ -44,9 +44,11 @@ namespace usbguard
     struct str_parent_hash : TAOCPP_PEGTL_STRING("parent-hash") {};
     struct str_via_port : TAOCPP_PEGTL_STRING("via-port") {};
     struct str_with_interface : TAOCPP_PEGTL_STRING("with-interface") {};
+    struct str_with_connect_type : TAOCPP_PEGTL_STRING("with-connect-type") {};
     struct str_serial : TAOCPP_PEGTL_STRING("serial") {};
     struct str_if : TAOCPP_PEGTL_STRING("if") {};
     struct str_id : TAOCPP_PEGTL_STRING("id") {};
+    struct str_label : TAOCPP_PEGTL_STRING("label") {};
 
     struct str_all_of : TAOCPP_PEGTL_STRING("all-of") {};
     struct str_one_of : TAOCPP_PEGTL_STRING("one-of") {};
@@ -163,6 +165,9 @@ namespace usbguard
     struct serial_attribute
       : action<serial_actions, rule_attribute<str_serial, string_value>> {};
 
+    struct with_connect_type_attribute
+      : action<with_connect_type_actions, rule_attribute<str_with_connect_type, string_value>> {};
+
     struct via_port_attribute
       : action<via_port_actions, rule_attribute<str_via_port, string_value>> {};
 
@@ -172,6 +177,9 @@ namespace usbguard
     struct condition_attribute
       : action<condition_actions, rule_attribute<str_if, condition>> {};
 
+    struct label_attribute
+      : action<label_actions, rule_attribute<str_label, string_value>> {};
+
     struct rule_attributes
       : sor<id_attribute,
         name_attribute,
@@ -180,7 +188,9 @@ namespace usbguard
         serial_attribute,
         via_port_attribute,
         with_interface_attribute,
-        condition_attribute> {};
+        with_connect_type_attribute,
+        condition_attribute,
+        label_attribute> {};
 
     /*
      * Rule target
@@ -188,19 +198,27 @@ namespace usbguard
     struct target
       : sor<str_allow, str_block, str_reject, str_match, str_device> {};
 
+    /*
+     * Comment
+     */
+    struct comment
+      : seq<star<ascii::blank>, if_must<one<'#'>,
+        star<seq<not_at<eof>, any>>>> {};
+
     /*
      * Rule
      */
     struct rule
       : seq<target,
         opt<plus<ascii::blank>, device_id>,
-        opt<plus<ascii::blank>, list<rule_attributes, plus<ascii::blank>>>> {};
+        opt<plus<ascii::blank>, list<rule_attributes, plus<ascii::blank>>>,
+        opt<comment>> {};
 
     /*
      * Grammar entry point
      */
     struct rule_grammar
-      : until<eof, must<rule>> {};
+      : until<eof, must<sor<comment, rule>>> {};
   } /* namespace RuleParser */
 } /* namespace usbguard */
 
