@@ -38,20 +38,20 @@ namespace usbguard
   const uint32_t Rule::ImplicitID = std::numeric_limits<uint32_t>::max() - 1;
 
   Rule::Rule()
-    : d_pointer(usbguard::make_unique<RulePrivate>(*this))
+    : d_pointer(usbguard::make_unique<RulePrivate>())
   {
   }
 
   Rule::~Rule() = default;
 
   Rule::Rule(const Rule& rhs)
-    : d_pointer(usbguard::make_unique<RulePrivate>(*this, *rhs.d_pointer))
+    : d_pointer(usbguard::make_unique<RulePrivate>(*rhs.d_pointer))
   {
   }
 
   const Rule& Rule::operator=(const Rule& rhs)
   {
-    d_pointer.reset(new RulePrivate(*this, *rhs.d_pointer));
+    d_pointer.reset(new RulePrivate(*rhs.d_pointer));
     return *this;
   }
 
@@ -115,6 +115,46 @@ namespace usbguard
     return d_pointer->attributeSerial();
   }
 
+  void Rule::setLabel(const std::string& value)
+  {
+    d_pointer->setLabel(value);
+  }
+
+  const std::string& Rule::getLabel() const
+  {
+    return d_pointer->getLabel();
+  }
+
+  const Rule::Attribute<std::string>& Rule::attributeLabel() const
+  {
+    return d_pointer->attributeLabel();
+  }
+
+  Rule::Attribute<std::string>& Rule::attributeLabel()
+  {
+    return d_pointer->attributeLabel();
+  }
+
+  void Rule::setWithConnectType(const std::string& value)
+  {
+    d_pointer->setWithConnectType(value);
+  }
+
+  const std::string& Rule::getWithConnectType() const
+  {
+    return d_pointer->getWithConnectType();
+  }
+
+  const Rule::Attribute<std::string>& Rule::attributeWithConnectType() const
+  {
+    return d_pointer->attributeWithConnectType();
+  }
+
+  Rule::Attribute<std::string>& Rule::attributeWithConnectType()
+  {
+    return d_pointer->attributeWithConnectType();
+  }
+
   void Rule::setName(const std::string& value)
   {
     d_pointer->setName(value);
@@ -239,12 +279,13 @@ namespace usbguard
   Rule::operator bool() const
   {
     return !(getTarget() == Target::Unknown ||
-        getTarget() == Target::Invalid);
+        getTarget() == Target::Invalid ||
+        getTarget() == Target::Empty);
   }
 
-  std::string Rule::toString(bool invalid) const
+  std::string Rule::toString(bool invalid, bool hide_serial) const
   {
-    return d_pointer->toString(invalid);
+    return d_pointer->toString(invalid, hide_serial);
   }
 
   void Rule::updateMetaDataCounters(bool applied, bool evaluated)
@@ -272,7 +313,8 @@ namespace usbguard
     { "block", Rule::Target::Block },
     { "reject", Rule::Target::Reject },
     { "match", Rule::Target::Match },
-    { "device", Rule::Target::Device }
+    { "device", Rule::Target::Device },
+    { "", Rule::Target::Empty }
   };
 
   const std::string Rule::targetToString(const Rule::Target target)
